<?php
/**
 * Table of Contents
 *
 * socrates_v5_posts_pagination ( pagination )
 * socrates_v5_comment_layout ( comment layout )
 * socrates_v5_mobile_nav ( mobile navigation )
 * socrates_v5_custom_logo ( custom image logo )
 * socrates_v5_body_class ( filter body classes )
 * socrates_v5_dynamic_css ( dynamics CSS code )
 * socrates_v5_company_url_sc ( site URL shortcode )
 * socrates_v5_company_name_sc ( site URL shortcode )
 */

if ( ! function_exists( 'socrates_v5_posts_pagination' ) ) : 

	/**
	 * Output post pagination
	 *
	 * @since 1.0
	 */
	function socrates_v5_posts_pagination( $atts = false ) {

		// The output will be stored here
		$output = '';

		if ( is_integer( get_query_var( 'paged' ) ) ) {
			$paged = get_query_var( 'paged' );
		} elseif ( is_integer( get_query_var( 'page' ) ) ) {
			$paged = get_query_var( 'page' );
		}

		if ( ! isset( $atts['force_number'] ) ) $force_number = false; else $force_number = $atts['force_number'];
		if ( ! isset( $atts['pages'] ) ) $pages = false; else $pages = $atts['pages'];
		if ( ! isset( $atts['type'] ) ) $type = 'numbered'; else $type = $atts['type'];
		$range = 2;

		$showitems = ($range * 2)+1;  

		if ( empty ( $paged ) ) { $paged = 1; }

		if ( $pages == '' ) {
			global $wp_query;
			$pages = $wp_query->max_num_pages;
			if( ! $pages ) {
				$pages = 1;
			}
		}

		if( 1 != $pages ) {

			?>
			<div class="pagination pagination-type-<?php echo esc_attr( $type ); ?>">
				<ul class="clearfix">
					<?php

						if ( $type == 'numbered' ) {

							if($paged > 2 && $paged > $range+1 && $showitems < $pages) { echo "<li class='inactive'><a href='".get_pagenum_link(1)."'>&laquo;</a></li>"; }
							if($paged > 1 && $showitems < $pages) { echo "<li class='inactive'><a href='".get_pagenum_link($paged - 1)."' >&lsaquo;</a></li>"; }

							for ($i=1; $i <= $pages; $i++){
								if (1 != $pages &&(!($i >= $paged+$range+1 || $i <= $paged-$range-1) || $pages <= $showitems)){
									echo ($paged == $i)? "<li class='active'><a href='".get_pagenum_link($i)."'>".$i."</a></li>":"<li class='inactive'><a class='inactive' href='".get_pagenum_link($i)."'>".$i."</a></li>";
								}
							}

							if ($paged < $pages && $showitems < $pages) { echo "<li class='inactive'><a href='".get_pagenum_link($paged + 1)."'>&rsaquo;</a></li>"; } 
							if ($paged < $pages-1 &&  $paged+$range-1 < $pages && $showitems < $pages) { echo "<li class='inactive'><a href='".get_pagenum_link($pages)."'>&raquo;</a></li>"; }

						} elseif ( $type == 'prevnext' ) {

							if($paged > 1 ) { echo "<li class='inactive fl'><a href='".get_pagenum_link($paged - 1)."' >" . esc_html__( 'Newer', 'socrates-v5' ) . "</a></li>"; }
							if ($paged < $pages ) { echo "<li class='inactive fr'><a href='".get_pagenum_link($paged + 1)."'>" . esc_html__( 'Older', 'socrates-v5' ) . "</a></li>"; } 

						} elseif ( $type == 'default' ) {

							posts_nav_link();

						}

						if ( $type == 'loadmore' ) {
							if ($paged < $pages ) { 
								echo "<li class='pagination-load-more active'><span class='pagination-load-more-line'></span><a href='".get_pagenum_link($paged + 1)."'><span class='fa fa-refresh'></span>" . esc_html__( 'LOAD MORE', 'socrates-v5' ) . "</a></li>";
							} else {
								echo "<li class='pagination-load-more inactive'><span class='pagination-load-more-line'></span><a href='#'>" . esc_html__( 'NO MORE POSTS', 'socrates-v5' ) . "</a></li>";
							}
						}
						
					?>
				</ul>

				<?php if ( $type == 'loadmore' ) : ?>
					<div class="load-more-temp"></div>
				<?php endif; ?>

			</div><!-- .pagination --><?php
		}

	}

endif;  // End if mdrt_posts_slider exists

if ( ! function_exists( 'socrates_v5_comment_layout' ) ) :

	/**
	 * Template for comments and pingbacks.
	 *
	 * @since 1.0
	 */
	function socrates_v5_comment_layout( $comment, $args, $depth ) {

		$GLOBALS['comment'] = $comment;
		
		switch ( $comment->comment_type ) :
			
			case 'pingback' :
			case 'trackback' :
				?>
				<li class="comments-pingback">
					<p><?php esc_html_e( 'Pingback:', 'socrates-v5' ); ?> <?php comment_author_link(); ?><?php edit_comment_link( esc_html__( '(Edit)', 'socrates-v5' ), ' ' ); ?></p>
				<?php
			break;
			default :

				?>

					<li <?php comment_class( 'comment' ); ?> id="comment-<?php comment_ID(); ?>">

						<div class="comment-inner">

							<span class="comment-author-avatar"><?php echo get_avatar( $comment, 65 ); ?></span>

							<div class="comment-info clearfix">

								<ul class="comment-meta clearfix">
									<li class="comment-meta-author"><?php echo get_comment_author_link(); ?></li>
									<li class="comment-meta-date"><?php echo get_comment_date(); ?></li>
								</ul>

								<span class="comment-reply">
									<?php edit_comment_link( esc_html__( 'Edit comment', 'socrates-v5' ) ); ?>
									<?php comment_reply_link( array_merge( $args, array( 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
								</span>

							</div><!-- .comment-info -->

							<div class="comment-main clearfix">
								
								<?php if ( $comment->comment_approved == '0' ) : ?>
									<p><em><?php esc_html_e( 'Your comment is awaiting moderation.', 'socrates-v5' ); ?></em></p>
								<?php endif; ?>
								<?php comment_text(); ?>

							</div><!-- .comment-main -->

						</div><!-- .comment-inner -->

					<?php

				break;
		endswitch;

	}

endif; // End if socrates_v5_comment_layout

if ( ! function_exists( 'socrates_v5_mobile_nav' ) ) :

	/**
	 * Handles output of mobile nav
	 *
	 * @since 1.0
	 */
	function socrates_v5_mobile_nav( $location = 'primary' ) {

		$mobile_nav_output = '';
		if( has_nav_menu($location) ) {
			
			$locations = get_nav_menu_locations();
			$menu = wp_get_nav_menu_object($locations[$location]);
			$menu_items = wp_get_nav_menu_items($menu->term_id);
			$mobile_nav_output = '';
			
			?>

			<select>
				<option><?php esc_html_e( '- Select Page -', 'socrates-v5' ); ?></option>
				<?php foreach ( $menu_items as $key => $menu_item ) : ?>
					<?php
						$title = $menu_item->title;
						$url = $menu_item->url;
						$nav_selected = '';
					?>
					<?php if($menu_item->post_parent !== 0) : ?>
						<option value="<?php echo esc_url( $url ); ?>"> - <?php echo esc_html( $title ); ?></option>
					<?php else : ?>
						<option value="<?php echo esc_url( $url ); ?>"><?php echo esc_html( $title ); ?></option>
					<?php endif; ?>
				<?php endforeach; ?>
			</select>
			<?php

		}

	}

endif; // End if socrates_v5_mobile_nav

if ( ! function_exists( 'socrates_v5_custom_logo' ) ) :

	/**
	 * Displays custom logo
	 *
	 * @since 1.0
	 */
	function socrates_v5_custom_logo() {
		if ( function_exists( 'the_custom_logo' ) ) {
			echo '<div itemscope itemtype="http://schema.org/Organization">';
				the_custom_logo();
			echo '</div>';
		}
	}

endif; // End if socrates_v5_custom_logo exists

if ( ! function_exists( 'socrates_v5_body_class' ) ) :

	/**
	 * Filter body classes
	 *
	 * @since 1.0
	 */
	function socrates_v5_body_class( $classes ) {

		// layout class
		$classes[] = 'body-general-layout-' . socrates_v5_get_theme_mod( 'general_layout', 'wrapped' );

		// logo position class
		$classes[] = 'body-logo-position-' . socrates_v5_get_theme_mod( 'logo_position', 'left' );

		// fitvids
		if ( socrates_v5_get_theme_mod( 'fitvids', 1 ) ) {
			$classes[] = 'body-fitvids-enabled';
		}

		// pass it back
		return $classes;

	}

endif; // End if socrates_v5_body_class exists
add_filter( 'body_class', 'socrates_v5_body_class' );

if ( ! function_exists( 'socrates_v5_dynamic_css' ) ) : 

	/**
	 * Dynamic CSS
	 *
	 * @since 1.0
	 */
	function socrates_v5_dynamic_css() {

		// no dynamic CSS if page builder templates
		if ( is_page_template( 'template-page-builders.php' ) ) {
			return;
		}

		// container width
		$container_width = socrates_v5_get_container_width() . 'px';

		// header image
		$header_image = get_header_image();

		// header image post/page
		if ( is_singular( array( 'post', 'page' ) ) || is_home() ) {
			$post_id = get_the_ID();
			if ( is_home() ) {
			$post_id = get_option( 'page_for_posts' );
			}
			if ( $custom_header_image = socrates_v5_get_post_meta( $post_id, 'custom_header_image' ) ) {
			$custom_header_image = wp_get_attachment_image_src( $custom_header_image, 'full' );
			$header_image = $custom_header_image[0];
			}
		}

		// header image tag/category
		if ( is_category() || is_tag() ) {

			// current term ID
			$current_term_id = get_queried_object()->term_id;

			// default to false
			$custom_image = false;

			// if category
			if ( is_category() ) {
				$term_meta = get_option( 'socrates_v5_category_meta' );
				if ( isset( $term_meta[ $current_term_id ] ) ) { 
					$custom_image = $term_meta[ $current_term_id ]['socrates_v5_category_img']; 
				}

			// if tag
			} elseif ( is_tag() ) {
				$term_meta = get_option( 'socrates_v5_tag_meta' );
				if ( isset( $term_meta[ $current_term_id ] ) ) { 
					$custom_image = $term_meta[ $current_term_id ]['socrates_v5_tag_img']; 
				}
			}

			// if the term has a custom image
			if ( $custom_image ) {
				$header_image = wp_get_attachment_image_src( $custom_image, 'full' );
				$header_image = $header_image[0];
			}

		}

		// header min height
		$header_min_height = socrates_v5_get_theme_mod( 'header_min_height', '100' );

		// header padding vertical
		$header_padding_ver = socrates_v5_get_theme_mod( 'header_padding_ver', '50' );

		// header padding horizontal
		$header_padding_hor = socrates_v5_get_theme_mod( 'header_padding_hor', '0' );

		// content padding
		$content_padding = socrates_v5_get_theme_mod( 'content_padding', '0' );

		// top bar background color
		$top_bar_bg_color = socrates_v5_get_theme_mod( 'top_bar_bg_color', '#22242a' );

		// top bar text color
		$top_bar_color = socrates_v5_get_theme_mod( 'top_bar_color', '#fff' );

		// top bar submenu background color
		$top_bar_submenu_bg_color = socrates_v5_get_theme_mod( 'top_bar_submenu_bg_color', '#191a1f' );

		// top bar submenu text color
		$top_bar_submenu_color = socrates_v5_get_theme_mod( 'top_bar_submenu_color', '#fff' );

		// header background color
		$header_bg_color = socrates_v5_get_theme_mod( 'header_bg_color', '#292c33' );

		// header title color
		$header_title_color = socrates_v5_get_theme_mod( 'header_title_color', '#fff' );

		// header title color
		$header_subtitle_color = socrates_v5_get_theme_mod( 'header_subtitle_color', '#fff' );

		// navigation background color
		$nav_bg_color = socrates_v5_get_theme_mod( 'nav_bg_color', '#fff' );

		// navigation text color
		$nav_color = socrates_v5_get_theme_mod( 'nav_color', '#181818' );

		// navigation aside text color
		$nav_aside_color = socrates_v5_get_theme_mod( 'nav_aside_color', '#ffffff' );

		// navigation submenu background color
		$nav_submenu_bg_color = socrates_v5_get_theme_mod( 'nav_submenu_bg_color', '#22242a' );

		// navigation submenu text color
		$nav_submenu_color = socrates_v5_get_theme_mod( 'nav_submenu_color', '#fff' );

		// footer background color
		$footer_bg_color = socrates_v5_get_theme_mod( 'footer_bg_color', '#22242a' );
		
		// footer widgets link color
		$footer_link_color = socrates_v5_get_theme_mod( 'footer_link_color', '#4082c6' );
		
		// footer bottom bg color
		$footer_bottom_bg_color = socrates_v5_get_theme_mod( 'footer_bottom_bg_color', '#fff' );

		// footer bottom text color
		$footer_bottom_text_color = socrates_v5_get_theme_mod( 'footer_bottom_text_color', '#444' );

		// footer bottom link color
		$footer_bottom_link_color = socrates_v5_get_theme_mod( 'footer_bottom_link_color', '#4082c6' );
		
		// footer widgets text color
		$footer_widget_text_color = socrates_v5_get_theme_mod( 'footer_widget_text_color', '#fff' );

		// text color
		$text_color = socrates_v5_get_theme_mod( 'text_color', '#444' );

		// headings color
		$headings_color = socrates_v5_get_theme_mod( 'headings_color', '#292c33' );

		// link color
		$link_color = socrates_v5_get_theme_mod( 'link_color', '#4082c6' );

		// accent color
		$accent_color = socrates_v5_get_theme_mod( 'accent_color', '#4082c6' );

		// fonts
		$primary_font = esc_html( socrates_v5_get_theme_mod( 'primary_font', 'Lato' ) );
		$secondary_font = esc_html( socrates_v5_get_theme_mod( 'secondary_font', 'Montserrat' ) );

		// nav text transform
		$nav_text_transform = socrates_v5_get_theme_mod( 'nav_text_transform', 'uppercase' );

		// headings underline
		$headings_underline = socrates_v5_get_theme_mod( 'headings_underline', 1 );

		// masonry title color
		$masonry_title_color = socrates_v5_get_theme_mod( 'masonry_title_color', '#000000' );

		// font sizes
		$logo_title_font_size = socrates_v5_get_theme_mod( 'logo_title_font_size', '34' );
		$logo_tagline_font_size = socrates_v5_get_theme_mod( 'logo_tagline_font_size', '20' );
		$body_font_size = socrates_v5_get_theme_mod( 'body_font_size', '16' );
		$page_title_font_size = socrates_v5_get_theme_mod( 'page_title_font_size', '35' );
		$post_single_title_font_size = socrates_v5_get_theme_mod( 'post_single_title_font_size', '35' );
		$post_listing_title_font_size = socrates_v5_get_theme_mod( 'post_listing_title_font_size', '28' );
		$primary_nav_font_size = socrates_v5_get_theme_mod( 'primary_nav_font_size', '16' );
		$primary_nav_submenu_font_size = socrates_v5_get_theme_mod( 'primary_nav_submenu_font_size', '13' );
		$widget_title_font_size = socrates_v5_get_theme_mod( 'widget_title_font_size', '18' );
		$content_h1 = socrates_v5_get_theme_mod( 'content_h1_font_size', '33' );
		$content_h2 = socrates_v5_get_theme_mod( 'content_h2_font_size', '30' );
		$content_h3 = socrates_v5_get_theme_mod( 'content_h3_font_size', '27' );
		$content_h4 = socrates_v5_get_theme_mod( 'content_h4_font_size', '24' );
		$content_h5 = socrates_v5_get_theme_mod( 'content_h5_font_size', '21' );
		$content_h6 = socrates_v5_get_theme_mod( 'content_h6_font_size', '18' );
		$content_h1_phone = socrates_v5_get_theme_mod( 'content_h1_font_size_phone', '26' );
		$content_h2_phone = socrates_v5_get_theme_mod( 'content_h2_font_size_phone', '24' );
		$content_h3_phone = socrates_v5_get_theme_mod( 'content_h3_font_size_phone', '22' );
		$content_h4_phone = socrates_v5_get_theme_mod( 'content_h4_font_size_phone', '20' );
		$content_h5_phone = socrates_v5_get_theme_mod( 'content_h5_font_size_phone', '18' );
		$content_h6_phone = socrates_v5_get_theme_mod( 'content_h6_font_size_phone', '16' );
		$footer_bottom_font_size = socrates_v5_get_theme_mod( 'footer_bottom_font_size', '12' );
		$masonry_title_font_size = socrates_v5_get_theme_mod( 'masonry_title_font_size', '17' );

		// font weights
		$logo_title_font_weight = socrates_v5_get_theme_mod( 'logo_title_font_weight', '700' );
		$logo_tagline_font_weight = socrates_v5_get_theme_mod( 'logo_tagline_font_weight', '400' );
		$body_font_weight = socrates_v5_get_theme_mod( 'body_font_weight', '400' );
		$page_title_font_weight = socrates_v5_get_theme_mod( 'page_title_font_weight', '500' );
		$post_single_title_font_weight = socrates_v5_get_theme_mod( 'post_single_title_font_weight', '500' );
		$post_listing_title_font_weight = socrates_v5_get_theme_mod( 'post_listing_title_font_weight', '500' );
		$primary_nav_font_weight = socrates_v5_get_theme_mod( 'primary_nav_font_weight', '600' );
		$primary_nav_submenu_font_weight = socrates_v5_get_theme_mod( 'primary_nav_submenu_font_weight', '600' );
		$footer_bottom_font_weight = socrates_v5_get_theme_mod( 'footer_bottom_font_weight', '400' );
		$widget_title_font_weight = socrates_v5_get_theme_mod( 'widget_title_font_weight', '500' );

		echo '<style type="text/css">';

			// container
			echo '.wrapper, .body-general-layout-wrapped #page-inner { max-width: ' . $container_width . '; }';

			// site title
			if ( socrates_v5_get_theme_mod( 'logo_display_title', 1 ) == 0 ) {
				echo '.site-title { position: absolute; clip: rect(1px, 1px, 1px, 1px); }';
			}

			// site tagline
			if ( socrates_v5_get_theme_mod( 'logo_display_tagline', 1 ) == 0 ) {
				echo '.site-description { position: absolute; clip: rect(1px, 1px, 1px, 1px); }';
			}

			// header image
			if ( ! empty( $header_image ) ) {
				if ( socrates_v5_get_theme_mod( 'header_bg_image_width', 'full' ) == 'full' ) {
					echo '#header { background-image: url("' . esc_url( $header_image ) . '"); }';
				} else {
					echo '#header .wrapper { background-image: url("' . esc_url( $header_image ) . '"); }';
				}
			}

			// header when title/tagline disabled
			if ( ! socrates_v5_is_logo_shown() && ! is_active_sidebar( 'sidebar-header' ) ) {
				echo 'body #header-inner .wrapper { padding: 0; }';
			}

			// min header height
			echo '#header-inner .wrapper { min-height: ' . $header_min_height . 'px; padding: ' . $header_padding_ver . 'px ' . $header_padding_hor . 'px; }';
			echo '@media only screen and ( min-width: 1025px ) and ( max-width: 1279px ) {body #header-inner .wrapper { min-height: ' . $header_min_height/1.25 . 'px; padding: ' . $header_padding_ver/1.25 . 'px ' . $header_padding_hor/1.25 . 'px; }}';
			echo '@media only screen and ( min-width: 768px ) and ( max-width: 1024px ) {body #header-inner .wrapper { min-height: ' . $header_min_height/1.6 . 'px; padding: ' . $header_padding_ver/1.6 . 'px ' . $header_padding_hor/1.6 . 'px; }}';
			echo '@media only screen and ( min-width: 480px ) and ( max-width: 767px ) {body #header-inner .wrapper { min-height: ' . $header_min_height/2.2 . 'px; padding: ' . $header_padding_ver/2.2 . 'px ' . $header_padding_hor/2.2 . 'px; }}';
			echo '@media only screen and ( min-width: 320px ) and ( max-width: 479px ) {body #header-inner .wrapper { min-height: ' . $header_min_height/3.8 . 'px; padding: ' . $header_padding_ver/3.8 . 'px ' . $header_padding_hor/3.8 . 'px; }}';

			// content padding
			echo '.page-template-default #content, .page-template-template-member #content { padding-right: ' . $content_padding . 'px; }';

			// top bar background color
			echo '#top-bar { background-color: ' . $top_bar_bg_color . '; }';

			// top bar text color
			echo '#top-bar-navigation .menu > li > a, #top-bar-navigation .menu a .fa, #top-bar-search .search-field, #top-bar-search .fa { color: ' . $top_bar_color . '; }';
			echo '#top-bar-search .search-field::-webkit-input-placeholder { color: ' . $top_bar_color . '; }';
			echo '#top-bar-search .search-field::-moz-placeholder { color: ' . $top_bar_color . '; }';
			echo '#top-bar-search .search-field:-ms-input-placeholder { color: ' . $top_bar_color . '; }';

			// top bar submenu background color
			echo '#top-bar-navigation .menu ul { background-color: ' . $top_bar_submenu_bg_color . '; }';

			// top bar submenu text color
			echo '#top-bar-navigation .menu ul li > a { color: ' . $top_bar_submenu_color . '; }';

			// header background color
			echo '#header { background-color: ' . $header_bg_color . '; }';

			// header title color
			echo '#logo .site-title { color: ' . $header_title_color . '; }';

			// header title color
			echo '#logo .site-description { color: ' . $header_subtitle_color . '; }';

			// navigation background color
			echo '#navigation { background-color: ' . $nav_bg_color . '; }';

			// navigation text color
			echo '#navigation .menu > li > a, #navigation .menu a .fa { color: ' . $nav_color . '; }';

			// navigation text color
			echo '#navigation-aside .menu > li > a, #navigation-aside .menu a .fa { color: ' . $nav_aside_color . '; }';

			// navigation submenu background color
			echo '#navigation .menu ul, #mobile-navigation-menu, #navigation-aside .menu ul { background-color: ' . $nav_submenu_bg_color . '; }';

			// navigation submenu text color
			echo '#navigation .menu ul li > a, #mobile-navigation-menu a, #mobile-navigation-menu li .fa, #navigation-aside .menu ul li > a { color: ' . $nav_submenu_color . '; }';

			// footer background color
			echo '#footer-widgets { background-color: ' . $footer_bg_color . '; }';
			
			// footer link color
			echo '#footer-widgets, #footer-widgets a, #footer-widgets ul { color: ' . $footer_link_color . '; }';
			echo '#footer-widgets { color: ' . $footer_widget_text_color . '; }';
			echo '#footer-widgets .widget-title { color: ' . $footer_link_color . '; }';
			echo '#footer-widgets .widget-title:after { background: ' . $footer_link_color . '; }';

			
			// footer bottom bg color
			echo '#footer-bottom { background: ' . $footer_bottom_bg_color . '; }';

			// footer bottom text color
			echo '#footer-bottom { color: ' . $footer_bottom_text_color . '; }';

			// footer bottom link color
			echo '#footer-bottom a { color: ' . $footer_bottom_link_color . '; }';
			echo '#footer-navigation .menu > li > a { color: ' . $footer_bottom_link_color . '; }';
			echo '#footer-navigation .menu > li > a:hover { color: ' . $footer_bottom_link_color . '; }';

			// text color 
			echo 'body, button, input, select, textarea { color: ' . $text_color . '; }';

			// headings color 
			echo 'h1, h2, h3, h4, h5, h6, .blog-post-single-title, .page-title { color: ' . $headings_color . '; }';

			// Mobile menu Icon
			echo '.header-mobile-nav-hook .st0{fill: ' . $accent_color . '; }';

			// accent bg color
			echo 'table thead, table tbody th, button, input[type="button"], input[type="reset"], input[type="submit"], .header-mobile-nav-hook, .post-s1-title:after, .post-s1-read-more a, .post-s2-read-more a, .post-s2-cats a, .post-s3-cats a, .post-s3-title:after, .pagination-load-more a, .pagination-type-numbered a, .blog-post-single-nav-button, .widget .tagcloud a, #footer-widgets .widget-title:after, .blog-post-single-title:after, .page-title:after, .blog-post-single-content h2:after, .blog-post-single-content h3:after, .blog-post-single-content h4:after, .blog-post-single-content h5:after, .comments-section-heading-title:after, .comment-reply-title:after, #sidebar .widget-title:after { background-color: ' . $accent_color . '; }';

			// accent text color
			echo '.comment-meta-author, #header-search .fa { color: ' . $accent_color . '; }';
			echo '.search-icon { border-color: ' . $accent_color . '; }';
			echo '.search-icon::after { background-color: ' . $accent_color . '; }';
			echo '.soc-toggle.active .soc-toggle-title,.soc-tabs-nav-item.active {background: ' . $accent_color . ';border-color:' . $accent_color . ' }';

			// link color
			echo 'a { color: ' . $link_color . '; }';

			// accent border color
			echo '.widget_search input[type="submit"] { border-color: ' . $accent_color . '; }';

			// primary font
			echo 'body, button, input, select, textarea, input[type="text"], input[type="email"], input[type="url"], input[type="password"], input[type="search"], textarea { font-family: "' . $primary_font . '"; }';

			// secondary font
			echo 'h1, h2, h3, h4, h5, h6, #logo .site-title { font-family: "' . $secondary_font . '"; }';

			// nav text transform
			echo '#top-bar-navigation .menu > li > a, #top-bar-navigation .menu ul li a, #navigation .menu > li > a, #navigation .menu ul li > a, #navigation-aside .menu > li > a, #navigation-aside .menu ul li > a, #mobile-navigation-menu a, #footer-copyright, #footer-navigation .menu > li > a { text-transform:' . $nav_text_transform . '; }';

			// headings underline
			if ( $headings_underline !== 1 ) {
				echo '.blog-post-single-title:after, .page-title:after, .blog-post-single-content h2:after, .blog-post-single-content h3:after, .blog-post-single-content h4:after, .blog-post-single-content h5:after { display: none; }';
			}

			// h1 font size
			echo 'h1 { font-size: ' . $content_h1 . 'px; }';

			// h2 font size
			echo 'h2 { font-size: ' . $content_h2 . 'px; }';

			// h3 font size
			echo 'h3 { font-size: ' . $content_h3 . 'px; }';

			// h4 font size
			echo 'h4 { font-size: ' . $content_h4 . 'px; }';

			// h5 font size
			echo 'h5 { font-size: ' . $content_h5 . 'px; }';

			// h6 font size
			echo 'h6 { font-size: ' . $content_h6 . 'px; }';

			echo '@media only screen and ( max-width: 767px ) {';

				// h1 font size
				echo 'h1 { font-size: ' . $content_h1_phone . 'px; }';

				// h2 font size
				echo 'h2 { font-size: ' . $content_h2_phone . 'px; }';

				// h3 font size
				echo 'h3 { font-size: ' . $content_h3_phone . 'px; }';

				// h4 font size
				echo 'h4 { font-size: ' . $content_h4_phone . 'px; }';

				// h5 font size
				echo 'h5 { font-size: ' . $content_h5_phone . 'px; }';

				// h6 font size
				echo 'h6 { font-size: ' . $content_h6_phone . 'px; }';

			echo '}';

			// logo title font size
			echo '#logo .site-title { font-size: ' . $logo_title_font_size . 'px; font-weight: ' . $logo_title_font_weight . '; }';

			// logo tagline font size
			echo '#logo .site-description { font-size: ' . $logo_tagline_font_size . 'px; font-weight: ' . $logo_tagline_font_weight . '; }';

			// body font size
			echo 'body, button, input, select, textarea { font-size: ' . $body_font_size . 'px; font-weight: ' . $body_font_weight . '; }';
			
			// page title font size
			echo '.page-title { font-size: ' . $page_title_font_size . 'px; font-weight: ' . $page_title_font_weight . '; }';
			
			// post title font size
			echo '.blog-post-single-title { font-size: ' . $post_single_title_font_size . 'px; font-weight: ' . $post_single_title_font_weight . '; }';
			
			// post listing title font size
			echo '.post-s1-title { font-size: ' . $post_listing_title_font_size . 'px; font-weight: ' . $post_listing_title_font_weight . '; }';
			
			// primary nav font size
			echo '#navigation .menu > li > a, #navigation-aside .menu > li > a { font-size: ' . $primary_nav_font_size . 'px; font-weight: ' . $primary_nav_font_weight . '; }';

			// primary nav submenu font size
			echo '#navigation .menu ul li > a, #navigation-aside .menu ul li > a { font-size: ' . $primary_nav_submenu_font_size . 'px; font-weight: ' . $primary_nav_submenu_font_weight . '; }';

			// widget title font size
			echo '#header-widgets .widget-title, #sidebar .widget-title, #footer-widgets .widget-title { font-size: ' . $widget_title_font_size . 'px; font-weight: ' . $widget_title_font_weight . '; }';
			
			// footer bottom font size
			echo '#footer-copyright, #footer-bottom a, #footer-navigation .menu > li > a, #footer-navigation .menu > li > a:hover { font-size: ' . $footer_bottom_font_size . 'px; font-weight: ' . $footer_bottom_font_weight . '; }';
			
			
			// masonry title
			echo '.post-s2-title { font-size: ' . $masonry_title_font_size . 'px; color: ' . $masonry_title_color . '; }';

		echo '</style>';

	}

endif; // End if socrates_v5_dynamic_css exists
add_action( 'wp_head', 'socrates_v5_dynamic_css' );


/**
 * Woocommerce remove default wrappers
 *
 * @since 1.0
 */
remove_action( 'woocommerce_before_main_content', 'woocommerce_output_content_wrapper',     10 );
remove_action( 'woocommerce_after_main_content',  'woocommerce_output_content_wrapper_end', 10 );

/**
 * Woocommerce add before wrapper
 *
 * @since 1.0
 */
function socrates_v5_woocommerce_before() {
	if ( socrates_v5_get_theme_mod( 'remove_woocommerce_sidebar', 1 ) == 1 ) {
		echo '<div id="content" class="col col-12">';
	} else {
		echo '<div id="content" class="col col-8">';
	}
} add_action( 'woocommerce_before_main_content', 'socrates_v5_woocommerce_before', 1 );

/**
 * Woocommerce add after wrapper
 *
 * @since 1.0
 */
function socrates_v5_woocommerce_after() {
	echo '</div>';
}add_action( 'woocommerce_after_main_content', 'socrates_v5_woocommerce_after', 99999 );

/**
 * Company URL shortcode
 *
 * @since 5.038
 */
function socrates_v5_company_url_sc() {

	return socrates_v5_get_theme_mod( 'company_url', '' );

} add_shortcode( 'company_url', 'socrates_v5_company_url_sc' );

/**
 * Company name shortcode
 *
 * @since 5.038
 */
function socrates_v5_company_name_sc() {

	return socrates_v5_get_theme_mod( 'company_name', '' );

} add_shortcode( 'company_name', 'socrates_v5_company_name_sc' );