<?php
/**
 * Table of Contents
 *
 * socrates_v5_term_options_scripts ( Enqueue admin scripts and styles )
 * socrates_v5_category_options_add ( Display option for categories )
 * socrates_v5_category_options_save ( Save option for categories )
 * socrates_v5_tag_options_add ( Display option for tags )
 * socrates_v5_tags_options_save ( Save option for tags )
 */

/**
 * Enqueue admin scripts and styles
 *
 * @since 1.0
 */
function socrates_v5_term_options_scripts( $hook ) {

	// if not on term edit
	if ( 'term.php' != $hook ) {
		return;
	}

	// the media library
	wp_enqueue_media();

	// custom scripts
	wp_register_script( 'socrates-v5-term-options-scripts', get_template_directory_uri() . '/js/term-options.js', array( 'jquery' ) );
	wp_localize_script( 'socrates-v5-term-options-scripts', 'meta_image',
		array(
			'title' => __( 'Set custom header image', 'socrates-v5' ),
			'button' => __( 'Use this image', 'socrates-v5' ),
		)
	);
	wp_enqueue_script( 'socrates-v5-term-options-scripts' );

	// custom CSS
	wp_enqueue_style( 'socrates-v5-term-options-style', get_template_directory_uri() . '/css/term-options.css' );

} add_action( 'admin_enqueue_scripts', 'socrates_v5_term_options_scripts' );

/**
 * Display option for categories
 *
 * @since 1.0
 */
function socrates_v5_category_options_add( $tag ) {

	$socrates_v5_category_meta = get_option( 'socrates_v5_category_meta' );
	$value = '';
	if ( isset( $socrates_v5_category_meta[ $tag->term_id ] ) ) { $value = esc_attr( $socrates_v5_category_meta[ $tag->term_id ]['socrates_v5_category_img'] ); }
	?>

	<tr class="form-field">
		<th scope="row" valign="top"><label for="socrates-v5-category-img"><?php esc_html_e( 'Custom Header Image', 'socrates-v5'); ?></label></th>
		<td>
			<div class="socrates-v5-term-options-upload <?php if ( $value ) echo 'socrates-v5-term-options-upload-active'; ?>">
		
				<div class="socrates-v5-term-options-upload-thumbnail">
					<?php 
						if ( $value ) {
							$image = wp_get_attachment_image_src( $value, 'medium' );
							echo '<img style="max-width: 100%;" src="' . $image[0] . '" />';					
						} 
					?>
				</div><!-- .socrates-v5-term-options-upload-thumbnail -->

				<p class="socrates-v5-term-options-upload-note"><?php esc_html_e( 'Click the image to edit or update', 'socrates-v5' ); ?></p>

				<a href="#" class="socrates-v5-term-options-upload-button"><?php esc_html_e( 'Set custom header image', 'socrates-v5' ); ?></a>
				<a href="#" class="socrates-v5-term-options-upload-clear"><?php esc_html_e( 'Remove custom header image', 'socrates-v5' ); ?></a>

				<input type="hidden" class="socrates-v5-term-options-upload-id" id="socrates-v5-category-img" name="socrates_v5_category_meta[<?php echo esc_attr( $tag->term_id ); ?>][socrates_v5_category_img]" value="<?php echo esc_attr( $value ); ?>" />

			</div><!-- .socrates-v5-term-options-upload -->
		</td>
	</tr>
	
	<?php

} add_action( 'edit_category_form_fields', 'socrates_v5_category_options_add' );

/**
 * Save option for categories
 *
 * @since 1.0
 */
function socrates_v5_category_options_save() {

	if ( isset( $_POST['socrates_v5_category_meta'] ) ) {

		if ( get_option('socrates_v5_category_meta' ) ) {
			$current_options = get_option( 'socrates_v5_category_meta' );
		} else {
			$current_options = array();
		}

		$post_info = $_POST['socrates_v5_category_meta'];
		if ( is_array( $post_info ) ) {
			foreach( $post_info as $key => $value ) {
				$current_options[$key] = $value;
			}
		}

		update_option('socrates_v5_category_meta', $current_options);
		
	}

} add_action( 'edit_category', 'socrates_v5_category_options_save' );

/**
 * Display option for tags
 *
 * @since 1.0
 */
function socrates_v5_tag_options_add( $tag ) {

	$socrates_v5_tag_meta = get_option( 'socrates_v5_tag_meta' );
	$value = '';
	if ( isset( $socrates_v5_tag_meta[ $tag->term_id ] ) ) { $value = esc_attr( $socrates_v5_tag_meta[ $tag->term_id ]['socrates_v5_tag_img'] ); }

	?>

	<tr class="form-field">
		<th scope="row" valign="top"><label for="socrates-v5-tag-img"><?php esc_html_e( 'Custom Header Image', 'socrates-v5'); ?></label></th>
		<td>
			<div class="socrates-v5-term-options-upload <?php if ( $value ) echo 'socrates-v5-term-options-upload-active'; ?>">
		
				<div class="socrates-v5-term-options-upload-thumbnail">
					<?php 
						if ( $value ) {
							$image = wp_get_attachment_image_src( $value, 'medium' );
							echo '<img style="max-width: 100%;" src="' . $image[0] . '" />';					
						} 
					?>
				</div><!-- .socrates-v5-term-options-upload-thumbnail -->

				<p class="socrates-v5-term-options-upload-note"><?php esc_html_e( 'Click the image to edit or update', 'socrates-v5' ); ?></p>

				<a href="#" class="socrates-v5-term-options-upload-button"><?php esc_html_e( 'Set custom header image', 'socrates-v5' ); ?></a>
				<a href="#" class="socrates-v5-term-options-upload-clear"><?php esc_html_e( 'Remove custom header image', 'socrates-v5' ); ?></a>

				<input type="hidden" class="socrates-v5-term-options-upload-id" id="socrates-v5-tag-img" name="socrates_v5_tag_meta[<?php echo esc_attr( $tag->term_id ); ?>][socrates_v5_tag_img]" value="<?php echo esc_attr( $value ); ?>" />

			</div><!-- .socrates-v5-term-options-upload -->
		</td>
	</tr>
	
	<?php

} add_action( 'edit_tag_form_fields', 'socrates_v5_tag_options_add' );

/**
 * Save option for tags
 *
 * @since 1.0
 */
function socrates_v5_tags_options_save() {

	if ( isset( $_POST['socrates_v5_tag_meta'] ) ) {

		if ( get_option('socrates_v5_tag_meta' ) ) {
			$current_options = get_option( 'socrates_v5_tag_meta' );
		} else {
			$current_options = array();
		}

		$post_info = $_POST['socrates_v5_tag_meta'];
		if ( is_array( $post_info ) ) {
			foreach( $post_info as $key => $value ) {
				$current_options[$key] = $value;
			}
		}

		update_option('socrates_v5_tag_meta', $current_options);
		
	}

} add_action( 'edit_post_tag', 'socrates_v5_tags_options_save' );