<?php

function socrates_v5_posts_list_widget_register() {
	register_widget( 'socrates_v5_posts_list_widget' );
} add_action( 'widgets_init', 'socrates_v5_posts_list_widget_register' );
class Socrates_V5_Posts_List_Widget extends WP_Widget {

	/**
	 * Register widget with WordPress.
	 */
	public function __construct() {
		parent::__construct(
			'socrates_v5_posts_list_widget', // Base ID
			esc_html__( 'Socrates - Posts List', 'socrates-v5' ), // Name
			array( 'description' => esc_html__( 'Show recent or popular posts.', 'socrates-v5' ) ) // Args
		);
	}

	/**
	 * Front-end display of widget.
	 *
	 * @see WP_Widget::widget()
	 *
	 * @param array $args     Widget arguments.
	 * @param array $instance Saved values from database.
	 */
	public function widget( $args, $instance ) {
		
		extract( $args );
		$title = apply_filters( 'widget_title', $instance['title'] );
		
		$amount = $instance['amount'];
		$type = $instance['type'];
		$blog_categories = $instance['blog_categories'];

		// Order by
		$orderby = 'date';
		if ( $type == 'popular' ) {
			$orderby = 'comment_count';
		}

		echo $before_widget;

		if ( ! empty( $title ) )
			echo $before_title . $title . $after_title;

		/* Start - Widget Content */

		// vars used
		$count = 0;
		$real_count = 0;
		$post_columns = 12;
		$max_columns = 12 / $post_columns;

		// query arguments
		$args = array(
			'post_type' => 'post',
			'posts_per_page' => $amount,
			'orderby' => $orderby
		);

		// blog categories
		if ( $blog_categories !== 'all' ) {
			$args['tax_query'] = array(
				array(
					'taxonomy' => 'category',
					'field'    => 'term_id',
					'terms'    => $blog_categories,
				),
			);
		}

		// do the query
		$socrates_v5_query = new WP_Query( $args );

		if ( $socrates_v5_query->have_posts() ) :

			?>

			<div class="posts-list-widget clearfix">

				<?php 

					// start posts loop
					while ( $socrates_v5_query->have_posts() ) : $socrates_v5_query->the_post();

						// increase counts
						$count++;
						$real_count++;

						// thumbnail sizes
						$thumb_width = 80;
						$thumb_height = 80;

						// set post data
						socrates_v5_set_post_vars( array(
							'post_class' => '',
							'thumb_width' => $thumb_width,
							'thumb_height' => $thumb_height,
							'thumb_crop' => true,
						));

						// post template
						get_template_part( 'template-parts/listing/post-s4' );

					// end posts loop
					endwhile; 

				?>

			</div><!-- .posts-list-widget -->

			<?php

		endif;

		wp_reset_postdata();

		/* End - Widget Content */

		echo $after_widget;

	}

	/**
	 * Sanitize widget form values as they are saved.
	 *
	 * @see WP_Widget::update()
	 *
	 * @param array $new_instance Values just sent to be saved.
	 * @param array $old_instance Previously saved values from database.
	 *
	 * @return array Updated safe values to be saved.
	 */
	public function update( $new_instance, $old_instance ) {
		
		$instance = array();
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['amount'] = strip_tags( $new_instance['amount'] );
		$instance['blog_categories'] = strip_tags( $new_instance['blog_categories'] );
		$instance['type'] = strip_tags( $new_instance['type'] );

		return $instance;

	}

	/**
	 * Back-end widget form.
	 *
	 * @see WP_Widget::form()
	 *
	 * @param array $instance Previously saved values from database.
	 */
	public function form( $instance ) {

		// Blog categories
		$blog_categories = get_terms( 'category' );
		$blog_categories_options = array(
			'all' => 'All',
		);
		foreach ( $blog_categories as $blog_category ) {
			$blog_categories_options[$blog_category->term_id] = $blog_category->name;
		}

		// Get values
		if ( isset( $instance[ 'title' ] ) ) $title = $instance[ 'title' ]; else $title = 'Recent Posts';
		if ( isset( $instance[ 'amount' ] ) ) $amount = $instance[ 'amount' ]; else $amount = '4';
		if ( isset( $instance[ 'blog_categories' ] ) ) $blog_categories = $instance[ 'blog_categories' ]; else $blog_categories = 'all';
		if ( isset( $instance[ 'type' ] ) ) $type = $instance[ 'type' ]; else $type = 'recent';

		?>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:', 'socrates-v5' ); ?></label> 
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'amount' ) ); ?>"><?php esc_html_e( 'Amount:', 'socrates-v5' ); ?></label> 
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'amount' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'amount' ) ); ?>" type="text" value="<?php echo esc_attr( $amount ); ?>" />
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'type' ) ); ?>"><?php esc_html_e( 'Type:', 'socrates-v5' ); ?></label> 
			<select class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'type' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'type' ) ); ?>">
				<option <?php if ( $type == 'recent' ) echo 'selected="selected"'; ?> value="recent"><?php esc_html_e( 'Recent', 'socrates-v5' ); ?></option>
				<option <?php if ( $type == 'popular' ) echo 'selected="selected"'; ?> value="popular"><?php esc_html_e( 'Popular', 'socrates-v5' ); ?></option>
			</select>
		</p>	
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'blog_categories' ) ); ?>"><?php esc_html_e( 'Blog Category:', 'socrates-v5' ); ?></label> 
			<select class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'blog_categories' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'blog_categories' ) ); ?>">
				<?php foreach ( $blog_categories_options as $cat_id => $cat_name ) : ?>
					<option <?php if ( $blog_categories == $cat_id ) echo 'selected="selected"'; ?> value="<?php echo esc_attr( $cat_id ); ?>"><?php echo esc_html( $cat_name ); ?></option>
				<?php endforeach; ?>
			</select>
		</p>	
		<?php 

	}

}